pub struct WorkingDirectoryPoolContext {
pub capacity: NonZeroU8,
pub auto_clean: Option<WorkingDirectoryAutoCleanOpts>,
pub remote_repository_url: GitUrl,
pub base_dir: Arc<WorkingDirectoryPoolBaseDir>,
pub signal_change: Option<PollingSignalsSender>,
}Expand description
Completed options, and WorkingDirectoryPoolBaseDir even has an open (lockable) file.
Fields
capacity: NonZeroU8auto_clean: Option<WorkingDirectoryAutoCleanOpts>Option since doing cleanup is optional (not because there are values in another place), None means do not do cleanup.
remote_repository_url: GitUrlbase_dir: Arc<WorkingDirectoryPoolBaseDir>signal_change: Option<PollingSignalsSender>Where to signal changes with the “current” link or working
directory status files. (Do not pass the
working_directory_change_signals here, those are for
signalling changes to the daemon to reload working directory
state; whereas the changes that are to be sent here
originate from the same daemon; the daemon would be
signalling itself.)