pub struct WorkingDirectoryPoolGuardMut<'pool> { /* private fields */ }Implementations
Sourceimpl<'pool> WorkingDirectoryPoolGuardMut<'pool>
impl<'pool> WorkingDirectoryPoolGuardMut<'pool>
The mut guard can also do shared operations; XX todo: just Deref, ah, would be double use of deref?
pub fn locked_base_dir<'s>(&'s self) -> WorkingDirectoryPoolBaseDirLock<'s>
Sourceimpl<'pool> WorkingDirectoryPoolGuardMut<'pool>
impl<'pool> WorkingDirectoryPoolGuardMut<'pool>
Sourcepub fn get_working_directory_mut<'guard>(
&'guard mut self,
working_directory_id: WorkingDirectoryId,
) -> Option<WorkingDirectoryWithPoolLockMut<'guard>>
pub fn get_working_directory_mut<'guard>( &'guard mut self, working_directory_id: WorkingDirectoryId, ) -> Option<WorkingDirectoryWithPoolLockMut<'guard>>
There’s also a method on WorkingDirectoryPool!
Sourcepub fn into_get_working_directory_mut(
self,
working_directory_id: WorkingDirectoryId,
) -> WorkingDirectoryWithPoolMut<'pool>
pub fn into_get_working_directory_mut( self, working_directory_id: WorkingDirectoryId, ) -> WorkingDirectoryWithPoolMut<'pool>
Similar to get_working_directory_mut but transfer ownership
of the guard into the result (does not unlock!).
Sourcepub fn get_first(&mut self) -> Result<WorkingDirectoryId>
pub fn get_first(&mut self) -> Result<WorkingDirectoryId>
Always gets a working directory, but doesn’t check for any best fit. If none was cloned yet, that is done now.
Sourcepub fn delete_working_directory(
&mut self,
working_directory_id: WorkingDirectoryId,
) -> Result<()>
pub fn delete_working_directory( &mut self, working_directory_id: WorkingDirectoryId, ) -> Result<()>
Note: may leave behind a broken current symlink, but that’s
probably the way it should be?
Sourcepub fn get_a_working_directory_for<'s>(
&'s mut self,
run_parameters: &RunParameters,
run_queues_data: &RunQueuesData<'_>,
) -> Result<WorkingDirectoryId>
pub fn get_a_working_directory_for<'s>( &'s mut self, run_parameters: &RunParameters, run_queues_data: &RunQueuesData<'_>, ) -> Result<WorkingDirectoryId>
Return the ~best working directory for the given run_parameters (e.g. with the requested commit checked out) and queue pipeline situation (e.g. if forced to change the checked out commit in a working directory, choose one that doesn’t have a commit checked out that is in the pipeline). Does not check out the commit needed for run_parameters!
Sourcepub fn clear_current_working_directory(&self) -> Result<()>
pub fn clear_current_working_directory(&self) -> Result<()>
Remove the symlink to the currently used working directory. TODO: this is a mess, always forgetting; at least move to a compile time checked API? What was the purpose, really: sure, it was to put in some check that the dir was actually removed normally? But then that ‘never’ happens anyway? Do the removal statically (and for the case of errors preventing the removal, just always remove at runtime when setting it anew / do tmp-and-rename)?