Struct WorkingDirectoryPoolOpts

pub struct WorkingDirectoryPoolOpts {
    pub base_dir: Option<PathBuf>,
    pub capacity: NonZeroU8,
    pub auto_clean: Option<WorkingDirectoryAutoCleanOpts>,
}
For RunConfigOpts configuration file. remote_repository_url is separate from this because that seemed to make more sense for the RunConfigOpts.

Fields

base_dir: Option<PathBuf>

Path to a directory where clones of the project to be benchmarked should be kept. By default at .evobench/working_directory_pool/.

capacity: NonZeroU8

How many clones of the target project should be maintained; more is better when multiple commits are benchmarked alternatively, to avoid needing a rebuild (and input re-preparation), but costing disk space.

auto_clean: Option<WorkingDirectoryAutoCleanOpts>

To enable working directory auto-cleaning, give the cleaning options. Currently “cleaning” just means full deletion by the runner with no involvement of the target project.