pub struct WorkingDirectoryPool { /* private fields */ }Implementations
Sourceimpl WorkingDirectoryPool
impl WorkingDirectoryPool
Sourcepub fn lock<'t>(&'t self, locker: &str) -> Result<WorkingDirectoryPoolGuard<'t>>
pub fn lock<'t>(&'t self, locker: &str) -> Result<WorkingDirectoryPoolGuard<'t>>
Get exclusive lock, but sharing self
Sourcepub fn lock_mut<'t>(
&'t mut self,
locker: &str,
) -> Result<WorkingDirectoryPoolGuardMut<'t>>
pub fn lock_mut<'t>( &'t mut self, locker: &str, ) -> Result<WorkingDirectoryPoolGuardMut<'t>>
Get exclusive lock, for exclusive access to self
Sourcepub fn open(
context: WorkingDirectoryPoolContext,
create_dir_if_not_exists: bool,
omit_check: bool,
) -> Result<WorkingDirectoryPoolAndLock>
pub fn open( context: WorkingDirectoryPoolContext, create_dir_if_not_exists: bool, omit_check: bool, ) -> Result<WorkingDirectoryPoolAndLock>
omit_check is passed on to WorkingDirectory::open (it
should only be set to true for dir listings).
Sourcepub fn get_working_directory(
&self,
working_directory_id: WorkingDirectoryId,
) -> Option<&WorkingDirectory>
pub fn get_working_directory( &self, working_directory_id: WorkingDirectoryId, ) -> Option<&WorkingDirectory>
Also see the method on WorkingDirectoryPoolGuard!
Sourcepub fn get_working_directory_path(
&self,
working_directory_id: WorkingDirectoryId,
) -> WorkingDirectoryPath
pub fn get_working_directory_path( &self, working_directory_id: WorkingDirectoryId, ) -> WorkingDirectoryPath
For cases where the working directory existing does not matter
Sourcepub fn get_working_directory_mut(
&mut self,
working_directory_id: WorkingDirectoryId,
) -> Option<&mut WorkingDirectory>
pub fn get_working_directory_mut( &mut self, working_directory_id: WorkingDirectoryId, ) -> Option<&mut WorkingDirectory>
Also see the method on WorkingDirectoryPoolGuard!
pub fn base_dir(&self) -> &Arc<WorkingDirectoryPoolBaseDir>
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
The value from the configuration as usize. Guaranteed to be
at least 1.
pub fn git_url(&self) -> &GitUrl
Sourcepub fn all_entries(
&self,
) -> impl Iterator<Item = (WorkingDirectoryId, &WorkingDirectory)>
pub fn all_entries( &self, ) -> impl Iterator<Item = (WorkingDirectoryId, &WorkingDirectory)>
This includes working dirs with errors, that (normally) must
be left aside and not used for processing! The returned
entries are sorted by WorkingDirectoryId
pub fn all_entries_mut( &mut self, ) -> impl Iterator<Item = (WorkingDirectoryId, &mut WorkingDirectory)>
Sourcepub fn active_entries(
&self,
) -> impl Iterator<Item = (WorkingDirectoryId, &WorkingDirectory)>
pub fn active_entries( &self, ) -> impl Iterator<Item = (WorkingDirectoryId, &WorkingDirectory)>
The entries that can be used for processing. The returned
entries are sorted by WorkingDirectoryId
pub fn active_entries_mut( &mut self, ) -> impl Iterator<Item = (WorkingDirectoryId, &mut WorkingDirectory)>
Sourcepub fn active_len(&self) -> usize
pub fn active_len(&self) -> usize
The number of entries that are not of Status::Error
Sourcepub fn process_in_working_directory<'pool, T>(
&'pool mut self,
working_directory_id: WorkingDirectoryId,
timestamp: &DateTimeWithOffset,
action: impl FnOnce(WorkingDirectoryWithPoolMut<'_>) -> Result<T>,
benchmarking_job_parameters: Option<&BenchmarkingJobParameters>,
context: &str,
have_other_jobs_for_same_commit: Option<&dyn Fn() -> bool>,
) -> Result<(T, WorkingDirectoryCleanupToken)>
pub fn process_in_working_directory<'pool, T>( &'pool mut self, working_directory_id: WorkingDirectoryId, timestamp: &DateTimeWithOffset, action: impl FnOnce(WorkingDirectoryWithPoolMut<'_>) -> Result<T>, benchmarking_job_parameters: Option<&BenchmarkingJobParameters>, context: &str, have_other_jobs_for_same_commit: Option<&dyn Fn() -> bool>, ) -> Result<(T, WorkingDirectoryCleanupToken)>
Runs the given action on the requested working directory with
the pool lock; the lock allows to use working directory
actions that require the lock, but it’s important to release
the lock as soon as possible via into_inner() (giving the
bare working directory, which can still be used for methods
that don’t require the lock), so that e.g. evobench wd
actions don’t block for the whole duration of an action
(i.e. a whole benchmarking run)! If the action returns with
an error, stores it as metadata with the directory and
changes the working directory to status Error. Returns an
error if a working directory with the given id doesn’t
exist. The returned WorkingDirectoryCleanupToken must be
passed to working_directory_cleanup. NOTE: is getting the
lock internally (multiple times for short durations, but also
passes the lock to action as mentioned above).
Sourcepub fn working_directory_cleanup(
&mut self,
cleanup: WorkingDirectoryCleanupToken,
) -> Result<()>
pub fn working_directory_cleanup( &mut self, cleanup: WorkingDirectoryCleanupToken, ) -> Result<()>
Possibly calls delete_working_directory, depending on what
the token says. NOTE: takes the lock internally, only when
needed.